@@ -6,10 +6,11 @@
  * @license   http://www.opensource.org/licenses/mit-license.html  MIT License
  */
 
-use phpseclib3\Crypt\Base;
+namespace phpseclib3\Tests\Functional\Net;
+
 use phpseclib3\Net\SFTP;
 
-class Functional_Net_SFTPLargeFileTest extends Functional_Net_SFTPTestCase
+class SFTPLargeFileTest extends SFTPTestCase
 {
     public static function setUpBeforeClass()
     {
