@@ -487,4 +487,15 @@ class ASN1Test extends PhpseclibTestCase
         //$x509 = new X509();
         //$x509->loadX509($cert);
     }
+
+    /**
+     * @group github2104
+     */
+    public function testBadBigInteger()
+    {
+        $key = pack('H*', 'a309486df62e19383a7faecd02423d44fb28773f36403f8a5e3c45f62549c855');
+        $decoded = ASN1::decodeBER($key);
+        $key = ASN1::asn1map($decoded[0], \phpseclib3\File\ASN1\Maps\DSAPublicKey::MAP);
+        $this->assertFalse($key);
+    }
 }
