@@ -1,13 +1,16 @@
 <?php
+
 /**
  * @author    Andreas Fischer <bantu@phpbb.com>
  * @copyright 2013 Andreas Fischer
  * @license   http://www.opensource.org/licenses/mit-license.html  MIT License
  */
 
-use \phpseclib3\Math\BigInteger;
+namespace phpseclib3\Tests\Unit\Math\BigInteger;
 
-class Unit_Math_BigInteger_DefaultTest extends Unit_Math_BigInteger_TestCase
+use phpseclib3\Math\BigInteger;
+
+class DefaultTest extends TestCase
 {
     public function getInstance($x = 0, $base = 10)
     {
